/* ***** BEGIN LICENSE BLOCK ***** 
 * Version: RCSL 1.0/RPSL 1.0 
 *  
 * Portions Copyright (c) 1995-2002 RealNetworks, Inc. All Rights Reserved. 
 *      
 * The contents of this file, and the files included with this file, are 
 * subject to the current version of the RealNetworks Public Source License 
 * Version 1.0 (the "RPSL") available at 
 * http://www.helixcommunity.org/content/rpsl unless you have licensed 
 * the file under the RealNetworks Community Source License Version 1.0 
 * (the "RCSL") available at http://www.helixcommunity.org/content/rcsl, 
 * in which case the RCSL will apply. You may also obtain the license terms 
 * directly from RealNetworks.  You may not use this file except in 
 * compliance with the RPSL or, if you have a valid RCSL with RealNetworks 
 * applicable to this file, the RCSL.  Please see the applicable RPSL or 
 * RCSL for the rights, obligations and limitations governing use of the 
 * contents of the file.  
 *  
 * This file is part of the Helix DNA Technology. RealNetworks is the 
 * developer of the Original Code and owns the copyrights in the portions 
 * it created. 
 *  
 * This file, and the files included with this file, is distributed and made 
 * available on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER 
 * EXPRESS OR IMPLIED, AND REALNETWORKS HEREBY DISCLAIMS ALL SUCH WARRANTIES, 
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY, FITNESS 
 * FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT. 
 * 
 * Technology Compatibility Kit Test Suite(s) Location: 
 *    http://www.helixcommunity.org/content/tck 
 * 
 * Contributor(s): 
 *  
 * ***** END LICENSE BLOCK ***** */ 

#ifndef _ASMRULPP_H_
#define _ASMRULPP_H_


/*
 * These two definintions aren't nested in ASMRuleExpression because
 * of the stoopid 16 bit compiler
 *
 */

enum Type {
    HX_RE_VARIABLE,
    HX_RE_INTEGER,
    HX_RE_FLOAT,
    HX_RE_OPERATOR
};


class Node
{
public:
    enum Type       m_Type;

    Node*           m_pLeft;
    Node*           m_pRight;
};


class ASMRuleExpression
{
public:
		    	ASMRuleExpression(const char* pExpression);
		    	~ASMRuleExpression();
    void		Dump();
    BOOL		Evaluate(IHXValues* pVars);
    BOOL		IsRightEdge();
    float		GetLeft();
    float		GetRight();
    int		        GetOperatorAsInt();
    void		SetRight( int );
    void		SetLeft( int );
    void		PreEvaluate(float*& pThreshold, UINT32& ulNumThreshold,
				IHXValues* pVariables, const char* pPreVar);
    BOOL		FindVariable(const char* pVariable);

    UINT32		GetNumThresholds() { return m_ulNumThresholds; }

private:
    class OperatorNode;
    friend class OperatorNode;

    enum Operator {
	HX_RE_GREATER,
	HX_RE_LESS,
	HX_RE_GREATEREQUAL,
	HX_RE_LESSEQUAL,
	HX_RE_EQUAL,
	HX_RE_NOTEQUAL,
	HX_RE_AND,
	HX_RE_OR
    };
    class VariableNode : public Node
    {
    public:
	char*		m_Data;
    };
    class IntegerNode : public Node
    {
    public:
	int		m_Data;
    };
    class FloatNode : public Node
    {
    public:
	float		m_Data;
    };
    class OperatorNode : public Node
    {
    public:
	enum Operator	m_Data;
    };

    Node*		Parse(char* pExpression, UINT32& ulNumThreshold); 
    void		RDump(Node* pNode);    
    void		RDelete(Node* pNode);
    float		REvaluate(Node* pNode, IHXValues* pVars);
    float		RPreEvaluate(Node* pNode, IHXValues* pVars,
				const char* pPreVar,
                                float*& pThreshold, UINT32& ulNumThreshold,
                                BOOL& bInvolvesTheOpenVariable);
    BOOL		RFindVariable(Node* pNode, const char* pVariable);

    UINT32		m_ulNumThresholds;
    Node*	    	m_pHead;
};

class ASMRule
{
public:
                        ASMRule();
			~ASMRule();
    void                SetExpression(const char* pExpression);
    void                Dump();
    IHXValues*		m_pRuleProps;
    ASMRuleExpression*  m_pRuleExpression;
};

#endif  /* ifndef _ASMRULPP_H_ */
